@@ -286,16 +286,16 @@ static gint prepare_binary_data_fo_save(const gchar* schema_name, xmlDocPtr doc)
         
     xmlXPathObjectPtr result = db_get_nodeset(doc, BAD_CAST query, ns);
 
+    g_free(query);
 //    struct cvs_MD5Context context;
 //    unsigned char checksum[16];
 
     if (result != NULL) {
         xmlNodeSetPtr nodeset = result->nodesetval;
 
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
+        gint size = nodeset->nodeNr - 1;
 
-        gint i = 0;
-        for (i= size; i >= 0; --i) {
+        for (gint i= size; i >= 0; --i) {
             gchar* bin_id = (gchar*)xmlGetProp(nodeset->nodeTab[i], BAD_CAST BINARY_NODE_TAG_FOR_FILENAME);
             if (bin_id == NULL) {
                 continue;
@@ -356,10 +356,9 @@ gint load_binary_data_to_doc(const gchar* schema_name, xmlDocPtr doc)
     if (result != NULL) {
         xmlNodeSetPtr nodeset = result->nodesetval;
 
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
+        gint size = nodeset->nodeNr - 1;
 
-        gint i = 0;
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
             gchar* bin_id = (gchar*)xmlGetProp(nodeset->nodeTab[i], BAD_CAST BINARY_NODE_TAG_FOR_FILENAME);
               DB_PDEBUG(3, "bin_id %s", bin_id);
             gchar* md5 = g_base64_encode((const guchar*)bin_id, strlen(bin_id));
@@ -626,10 +625,9 @@ gchar* get_id_text_notation(const gchar* schema_name)
     if (result != NULL) {
         xmlNodeSetPtr nodeset = result->nodesetval;
 
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;
+        gint size = nodeset->nodeNr - 1;
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
             gchar* content = (gchar*)xmlNodeGetContent(nodeset->nodeTab[i]);
             id_list = g_slist_prepend(id_list, content);
         }   
@@ -1356,16 +1354,14 @@ gint db_remove_node_by_id(const gchar* schema_name ,const gchar* id)
     }
     g_debug("REMOVE XPATH = %s", xpath_query);
     xmlXPathObjectPtr result = db_get_nodeset(doc, BAD_CAST xpath_query, ns);
-
+    g_free(xpath_query);
 
      if (result != NULL) {
 	    xmlNodeSetPtr nodeset = result->nodesetval;
 		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;
+        gint size = nodeset->nodeNr - 1;
 
-        for(i = size; i >= 0; --i) {
-		g_debug("Remove node %i", i);
+        for(gint i = size; i >= 0; --i) {
 		    xmlUnlinkNode(nodeset->nodeTab[i]);
 		    xmlFreeNode(nodeset->nodeTab[i]);
 		    
@@ -1383,6 +1379,7 @@ gint db_remove_node_by_id(const gchar* schema_name ,const gchar* id)
     g_free(id_ns_prefix);
     g_free(id_name);
     g_free(id_xpath);
+    xmlFree(ns);
     
     gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
     db_save_table(doc, schema_name, db_path);
@@ -1433,10 +1430,7 @@ GSList* db_get_node_by_id(const gchar* schema_name ,const gchar* id)
         } else {   
             xpath_query = g_strconcat(id_xpath, "[@",  id_ns_prefix, ":", id_name, "=", id, "]", NULL );
         }    
-    }
-
-    g_debug("XPATH = %s", xpath_query);
-    
+    }    
     
     g_debug("Find node, xpath: %s", xpath_query);
     g_free(id_ns_prefix);
@@ -1444,58 +1438,64 @@ GSList* db_get_node_by_id(const gchar* schema_name ,const gchar* id)
     g_free(id_xpath);
     
     xmlXPathObjectPtr result = db_get_nodeset(doc, BAD_CAST xpath_query, ns);
+    g_free(xpath_query);    
 
     GSList* doc_list = NULL; 
 
      if (result != NULL) {
 	    xmlNodeSetPtr nodeset = result->nodesetval;
 		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;		
+        gint size = nodeset->nodeNr - 1;
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
 		g_debug("Find node %i", i);
 //		    xmlUnlinkNode(nodeset->nodeTab[i]);
 	//	    xmlFreeNode(nodeset->nodeTab[i]);
 		    //xmlNodeGetContent
-
-		     
-		    
+  
 		    xmlNodePtr node = xmlCopyNode	( nodeset->nodeTab[i],1);
-		    		    xmlBufferPtr buf = xmlBufferCreate();
+
+		    xmlBufferPtr buf = xmlBufferCreate();
 		    xmlNodeDump(buf, 
-					  NULL, node, //nodeset->nodeTab[i], 
-					0,1);
-	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);//= xmlNodeListGetString(NULL , xmlDocGetRootElement	(doc),1); //(doc,nodeset->nodeTab[i],0 );
+				NULL, node, //nodeset->nodeTab[i], 
+				0,1);
+  		    xmlFreeNode(node);
+	        xmlChar* content = xmlStrdup((xmlChar*)xmlBufferContent(buf));//= xmlNodeListGetString(NULL , xmlDocGetRootElement	(doc),1); //(doc,nodeset->nodeTab[i],0 );
 	        
-	        
-	        
-	        g_printf("\n\nNODE Content: %s", content);
+
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 	        
+	        xmlBufferFree(buf);
+
             xmlDocPtr external_format = db_apply_revers_stylesheet(schema_name, elem, NULL);
 	        
-   	        g_printf("\n\nNODE Afte transform1: ");
+//   	        g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(schema_name, external_format);
 //DEBUG   	        xmlDocDump(stdout, external_format);
    	        	
 	        
-	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));  
-	        xmlFreeDoc(external_format);
+	        doc_list = g_slist_prepend(doc_list, external_format);//xmlCopyDoc(external_format, 1));  
+//	        xmlFreeDoc(external_format);
 	        xmlFreeDoc(elem);
-	        xmlFree(content);
+                
+                free(content);
+
 //		    if (nodeset->nodeTab[i]->type != XML_NAMESPACE_DECL) {
 //    	        nodeset->nodeTab[i] = NULL;
 //            }
-            
                     
         }
-        }
-         gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
-     db_save_table(doc, schema_name, db_path);
+            	xmlXPathFreeObject(result);	
+    }
+
+    xmlFree(ns);
+
+    gchar* db_path = cm_get_db_path_by_name_or_default(g_db_name);
+    db_save_table(doc, schema_name, db_path);
+    g_free(db_path); 
      
-     return doc_list;
+    return doc_list;
 }
 
 
@@ -1662,7 +1662,6 @@ void db_prepare(const gchar* db_name)
  
     //print_schemas_links();
     init_tables_store(TRUE);
-    DB_DEBUG(1,"!!!!!!!!!!!!!!!!AAAAAAAAAAAAA");
 }
 
 
