@@ -35,7 +35,7 @@
 #define INCLUDE_TEST_FUNC 1
 
 /* Max count of attemps for sending data to driver */
-#define MAX_KERNEL_SEND_ATTEMPT_COUNT 10
+#define MAX_KERNEL_SEND_ATTEMPT_COUNT 20
 
 /* Wake signal settings */
 #define WAKE_KERNEL_START_TIME "20"
@@ -105,9 +105,9 @@ static void shutdown_drivers();
 
 
 
-//#ifdef INCLUDE_TEST_FUNC
-//#include "../../test/kernel_test/kernel_test_func.c"
-//#endif
+#ifdef INCLUDE_TEST_FUNC
+#include "../../test/kernel_test/kernel_test_func.c"
+#endif
 
 
 /**************************************************/
@@ -139,7 +139,7 @@ gint kernel_initialization()
     set_wake_signal(WAKE_KERNEL_SIGNAL_ID, SET_SIGNAL_TEXT, 
                     WAKE_KERNEL_START_TIME, WAKE_KERNEL_REPEAT_TIME);
 
-    gint register_result = 0;
+   //gint register_result = 0;
    // if ((register_result = register_wake_signal()) != SUCCESS) {
    //     return register_result;
    // }
@@ -167,7 +167,6 @@ gint kernel_put_data(xmlDocPtr data)
 
     if (tr_data == NULL) {
         KERNEL_DEBUG(4) ("KERNEL: kernel_put_data; tr_data = NULL");
-        xmlFreeDoc(data);
         return FAILURE;
     } 
 
@@ -237,9 +236,6 @@ gint kernel_ext_put_text_data(xmlDocPtr request, xmlDocPtr* response)
 void kernel_shutdown()
 {
     KERNEL_DEBUG(1) ("KERNEL: shutdown START");
-
-    msa_module_shutdown();
-      
     G_LOCK(is_process_proceed);
     is_process_proceed = FALSE;
     G_UNLOCK(is_process_proceed);
@@ -253,9 +249,7 @@ void kernel_shutdown()
     free_reposityry_data();
   
     xmlFree(wake_kernel_signal);
-    wake_kernel_signal  = NULL;
-
-    msa_end();   
+    wake_kernel_signal  = NULL;;   
 
     KERNEL_DEBUG(1) ("KERNEL: shutdown END");
 }
@@ -387,9 +381,13 @@ static GList* get_targets(xmlDocPtr doc)
     for (gint i = 0; i < nodeset->nodeNr; ++i) {
         xmlUnlinkNode(nodeset->nodeTab[i]);
         xmlFreeNode(nodeset->nodeTab[i]);
+        nodeset->nodeTab[i] = NULL;
     }
     
+    // Kulakov: valgrind says that is already freed.
+    // Lomov: Valgrind is lier. Now all is well.
     xmlXPathFreeObject(result);
+    
     KERNEL_DEBUG(5) ("KERNEL: get_targets END");
     return targets;
 }
@@ -695,7 +693,8 @@ static gint send_data_to_driver(const target_data* target, const xmlDocPtr data)
     //xmlFreeDoc(data_with_target);
 
         
-    if (msa_disp_send_request(target->name, data_with_target) != 0) {
+    if (msa_disp_send_request(target->name, data_with_target) != SUCCESS) {
+	xmlFreeDoc(data_with_target);
         KERNEL_MESSAGE(2) ("KERNEL: Can't send data to driver (%s)", target->name);
         return ERROR_CANT_SEND_DATA;
     }
