@@ -22,6 +22,7 @@
 
 #ifndef _MSA_MODULE_H_
 #define _MSA_MODULE_H_
+#define _(String) gettext(String)
 
 #include <glib.h>
 
@@ -88,8 +89,13 @@
 #define DB_SAVE_ERROR_FRIENDS_PROFILE_CODE "314"
 #define DB_GET_ERROR_BINARY_CODE "321"
 #define DB_SAVE_ERROR_BINARY_CODE "322"
+
 #define DB_GET_ERROR_INBOX_MESSAGES_CODE "331"
 #define DB_GET_ERROR_OUTBOX_MESSAGES_CODE "332"
+
+#define DB_UPDATE_ERROR_INBOX_MESSAGES_CODE "333"
+#define DB_UPDATE_ERROR_OUTBOX_MESSAGES_CODE "334"
+
 #define DB_UPDATE_MESSAGE_INBOX_MESSAGES_CODE "333"
 #define DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_CODE "334"
 #define DB_GET_ERROR_INBOX_MESSAGE_CODE "335"
@@ -97,38 +103,43 @@
 #define DB_INIT_ERROR_CODE "351"
 
 /** db message text **/
-#define DB_SAVE_MESSAGE_PROFILE_TEXT "profile updated"
-#define DB_SAVE_ERROR_PROFILE_TEXT "profile wasn't updated"
-#define DB_GET_ERROR_PROFILE_TEXT "profile wasn't found"
-#define DB_SAVE_MESSAGE_FRIENDS_TEXT "friends list updated"
-#define DB_SAVE_ERROR_FRIENDS_TEXT "friends list wasn't updated"
-#define DB_GET_ERROR_FRIENDS_TEXT "friends list wasn't found"
-#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT "friend's profile updated"
-#define DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT "friend's profile wasn't updated"
-#define DB_GET_ERROR_BINARY_TEXT "image wasn't found"
-#define DB_SAVE_ERROR_BINARY_TEXT "image wasn't updated"
-#define DB_GET_ERROR_INBOX_MESSAGES_TEXT "inbox messages list wasn't saved" 
-#define DB_GET_ERROR_OUTBOX_MESSAGES_TEXT "outbox messages list wasn't saved" 
-#define DB_UPDATE_MESSAGE_INBOX_MESSAGES_TEXT "inbox messages list saved" 
-#define DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_TEXT "outbox messages list was saved" 
-#define DB_GET_ERROR_INBOX_MESSAGE_TEXT "inbox messages list wasn't found"
-#define DB_NEW_INBOX_MESSAGES_TEXT "new messages:"
-#define DB_INIT_ERROR_TEXT "db critical error"
+#define DB_SAVE_MESSAGE_PROFILE_TEXT _("profile updated")
+#define DB_SAVE_ERROR_PROFILE_TEXT _("profile wasn't updated")
+#define DB_GET_ERROR_PROFILE_TEXT _("profile wasn't found")
+#define DB_SAVE_MESSAGE_FRIENDS_TEXT _("friends list updated")
+#define DB_SAVE_ERROR_FRIENDS_TEXT _("friends list wasn't updated")
+#define DB_GET_ERROR_FRIENDS_TEXT _("friends list wasn't found")
+#define DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT _("friend's profile updated")
+#define DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT _("friend's profile wasn't updated")
+#define DB_GET_ERROR_BINARY_TEXT _("image wasn't found")
+#define DB_SAVE_ERROR_BINARY_TEXT _("image wasn't updated")
+
+#define DB_GET_ERROR_INBOX_MESSAGES_TEXT _("inbox messages list wasn't found")
+#define DB_GET_ERROR_OUTBOX_MESSAGES_TEXT _("outbox messages list wasn't found")
+
+#define DB_UPDATE_ERROR_INBOX_MESSAGES_TEXT _("inbox messages list wasn't saved")
+#define DB_UPDATE_ERROR_OUTBOX_MESSAGES_TEXT _("outbox messages list wasn't saved")
+
+#define DB_UPDATE_MESSAGE_INBOX_MESSAGES_TEXT _("inbox messages list saved")
+#define DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_TEXT _("outbox messages list was saved")
+#define DB_GET_ERROR_INBOX_MESSAGE_TEXT _("inbox messages list wasn't found") // FIXME not used const
+#define DB_NEW_INBOX_MESSAGES_TEXT _("new messages:")
+#define DB_INIT_ERROR_TEXT _("db critical error")
 
 /** Driver message code **/
 #define DRV_SETT_SAVED_CODE "410"
 
 /** Driver message text **/
-#define DRV_SETT_ERROR "Unable to save settings"
-#define DRV_SETT_SAVED "Settings saved"
-#define DRV_AUTH_ERROR "Authorization problem"
-#define DRV_REQ_ERROR "Unable to perform request"
-#define DRV_PROF_SAVED "Profile changed"
-#define DRV_CAPT_ERROR "Captcha"
-#define DRV_RESP_ERROR "Bad response from server"
-#define DRV_NETW_ERROR "Network problem"
-#define DRV_MESS_SEND "Message send"
-#define DRV_MESS_ERROR "Unable send message"
+#define DRV_SETT_ERROR _("Unable to save settings")
+#define DRV_SETT_SAVED _("Settings saved")
+#define DRV_AUTH_ERROR _("Authorization problem")
+#define DRV_REQ_ERROR _("Unable to perform request")
+#define DRV_PROF_SAVED _("Profile changed")
+#define DRV_CAPT_ERROR _("Captcha")
+#define DRV_RESP_ERROR _("Bad response from server")
+#define DRV_NETW_ERROR _("Network problem")
+#define DRV_MESS_SEND _("Message send")
+#define DRV_MESS_ERROR _("Unable send message")
 
 
 /** @enum msa_module_type
